"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ern_core_1 = require("ern-core");
const fs_readdir_recursive_1 = __importDefault(require("fs-readdir-recursive"));
const path_1 = __importDefault(require("path"));
const defaultReactNativePackagerHost = 'localhost';
const defaultReactNativePackagerPort = '8081';
const runnerHullPath = path_1.default.join(__dirname, 'hull');
class AndroidRunnerGenerator {
    get platform() {
        return 'android';
    }
    async generate(config) {
        let mustacheView = {};
        mustacheView = configureMustacheView(config, mustacheView);
        ern_core_1.shell.cp('-R', path_1.default.join(runnerHullPath, '*'), config.outDir);
        ern_core_1.shell.mv(path_1.default.join(config.outDir, 'app/src/main/java/com/walmartlabs/ern/miniapp'), path_1.default.join(config.outDir, 'app/src/main/java', getPackageFilePath(config)));
        const files = fs_readdir_recursive_1.default(config.outDir, (f) => !f.endsWith('.jar') && !f.endsWith('.png'));
        for (const file of files) {
            await ern_core_1.mustacheUtils.mustacheRenderToOutputFileUsingTemplateFile(path_1.default.join(config.outDir, file), mustacheView, path_1.default.join(config.outDir, file));
        }
    }
    async regenerateRunnerConfig(config) {
        let mustacheView = {};
        mustacheView = configureMustacheView(config, mustacheView);
        const subPathToRunnerConfig = 'app/src/main/java/com/walmartlabs/ern/miniapp/RunnerConfig.java';
        const pathToRunnerConfigHull = path_1.default.join(runnerHullPath, subPathToRunnerConfig);
        const pathToRunnerConfig = path_1.default.join(config.outDir, 'app/src/main/java', getPackageFilePath(config), 'RunnerConfig.java');
        ern_core_1.shell.cp(pathToRunnerConfigHull, pathToRunnerConfig);
        await ern_core_1.mustacheUtils.mustacheRenderToOutputFileUsingTemplateFile(pathToRunnerConfig, mustacheView, pathToRunnerConfig);
    }
}
exports.default = AndroidRunnerGenerator;
function getPackageFilePath(config) {
    return isOldRunner(config)
        ? 'com/walmartlabs/ern'
        : `com/walmartlabs/ern/${config.mainMiniAppName.toLowerCase()}`;
}
function isOldRunner(config) {
    var _a, _b;
    return !!((_b = (_a = config.extra) === null || _a === void 0 ? void 0 : _a.androidConfig) === null || _b === void 0 ? void 0 : _b.isOldRunner);
}
// Given a string returns the same string with its first letter capitalized
function pascalCase(str) {
    return `${str.charAt(0).toUpperCase()}${str.slice(1)}`;
}
function configureMustacheView(config, mustacheView) {
    var _a, _b, _c, _d, _e, _f, _g;
    const versions = ern_core_1.android.resolveAndroidVersions({
        reactNativeVersion: config.reactNativeVersion,
        ...(_a = config.extra) === null || _a === void 0 ? void 0 : _a.androidConfig,
    });
    mustacheView = Object.assign(mustacheView, versions);
    mustacheView.isReactNativeDevSupportEnabled =
        config.reactNativeDevSupportEnabled === true ? 'true' : 'false';
    mustacheView.miniAppName = config.mainMiniAppName;
    mustacheView.packagerHost =
        config.reactNativePackagerHost || defaultReactNativePackagerHost;
    mustacheView.packagerPort =
        config.reactNativePackagerPort || defaultReactNativePackagerPort;
    mustacheView.pascalCaseMiniAppName = pascalCase(config.mainMiniAppName);
    mustacheView.lowerCaseMiniAppName = config.mainMiniAppName.toLowerCase();
    mustacheView.artifactId =
        (_d = (_c = (_b = config.extra) === null || _b === void 0 ? void 0 : _b.androidConfig) === null || _c === void 0 ? void 0 : _c.artifactId) !== null && _d !== void 0 ? _d : `runner-ern-container-${config.mainMiniAppName.toLowerCase()}`;
    mustacheView.groupId =
        (_g = (_f = (_e = config.extra) === null || _e === void 0 ? void 0 : _e.androidConfig) === null || _f === void 0 ? void 0 : _f.groupId) !== null && _g !== void 0 ? _g : 'com.walmartlabs.ern';
    mustacheView.isOldRunner = isOldRunner(config);
    ern_core_1.injectReactNativeVersionKeysInObject(mustacheView, config.reactNativeVersion);
    return mustacheView;
}
//# sourceMappingURL=AndroidRunnerGenerator.js.map